# Description 

Used to create graph for tweets collected from a twitter api query. 


# Limitations 

Not a general purpose twitter library rather its focus is on andling collected twitter data. works a bridge between twittr api results and the neo4j databse graphs.
Implements result is the format described here. 

# Installation 

pip install twneo

# Example use 

